config

package
v0.0.0-...-ab3c899 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 8, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package config holds application settings coming from different sources. config.Load() is entrypoint and the returned Config instance should be shared with other modules.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	WorkDir string
	// contains filtered or unexported fields
}

Config represent application configurations

func Load

func Load() *Config

Load loads configuration using environment variables

Jump to